@@ -275,33 +275,46 @@ class BusinessSystemAPI:
         if data_status:
             data["data_status"] = data_status
         
-        response = self.client.get('/api/business_system/list', data=data)
+        response = self.client.post('/api/business_system/list', data=data)
         return response
     
     def update(
-        self,
-        business_system_data: Dict[str, Any],
-        execute_release: bool = False
-    ) -> Dict[str, Any]:
+            self,
+            business_system_data: List[Dict[str, Any]],
+            execute_release: bool = False
+        ) -> Dict[str, Any]:
         """
         更新业务系统
-        
+
         Args:
-            business_system_data: 业务系统数据
+            business_system_data: 业务系统数据列表（每个元素为一个业务系统字典）
             execute_release: 是否直接发布
-            
+
         Returns:
             操作结果
         """
-        if not isinstance(business_system_data, dict):
-            raise SARMValidationError("业务系统数据必须是字典类型")
-        
-        if 'business_system' not in business_system_data:
-            raise SARMValidationError("缺少 business_system 字段")
-        
-        # 验证业务系统数据
-        self._validate_business_system_data(business_system_data['business_system'])
-        
+        # 验证是否为列表类型
+        if not isinstance(business_system_data, list):
+            raise SARMValidationError("业务系统数据必须是列表类型")
+
+        # 验证列表不为空
+        if not business_system_data:
+            raise SARMValidationError("业务系统数据列表不能为空")
+
+        # 逐个验证列表中的业务系统数据
+        for item in business_system_data:
+            # 验证列表中的每个元素是否为字典
+            if not isinstance(item, dict):
+                raise SARMValidationError("业务系统列表中的元素必须是字典类型")
+
+            # 验证每个字典是否包含 'business_system' 字段
+            if 'business_system' not in item:
+                raise SARMValidationError("业务系统数据缺少 business_system 字段")
+
+            # 验证具体的业务系统数据
+            self._validate_business_system_data(item['business_system'])
+
+        # 发送请求更新业务系统
         response = self.client.post(
             '/api/business_system/update',
             data=business_system_data,
@@ -309,7 +322,7 @@ class BusinessSystemAPI:
         )
         return response
     
-    def delete_organize(self, organize_id: str) -> Dict[str, Any]:
+    def delete_organize(self, businessUniqueId: List[str]) -> Dict[str, Any]:
         """
         删除业务系统的组织关联
         
@@ -319,12 +332,12 @@ class BusinessSystemAPI:
         Returns:
             操作结果
         """
-        if not isinstance(organize_id, str):
-            raise SARMValidationError("组织ID必须是字符串类型")
+        if not isinstance(businessUniqueId, list):
+            raise SARMValidationError("业务系统ID列表必须是列表类型")
         
-        if organize_id.strip() == '':
-            raise SARMValidationError("组织ID不能为空字符串")
+        if not businessUniqueId:
+            raise SARMValidationError("业务系统ID列表不能为空")
         
-        data = {"organize_id": organize_id}
+        data = businessUniqueId
         response = self.client.delete('/api/business_system/delete_organize', data=data)
         return response 
\ No newline at end of file
