@@ -110,18 +110,33 @@ class CarrierAPI:
                 raise SARMValidationError(f"第{record_index}条记录的 port 必须在1-65535之间")
     def create_batch(
         self,
-        carriers: List[CarrierInsert],
+        carriers: List[Dict[str, Any]],
         execute_release: bool = False
     ) :
         """
         批量创建应用载体
         
         Args:
-            carriers: 应用载体数据列表
-            execute_release: 是否直接发布
+            carriers: 应用载体数据列表，每个元素为包含载体信息的字典
+            execute_release: 是否直接发布，默认为False进入预处理状态
             
         Returns:
-            批量操作结果
+            Dict[str, Any]: 批量操作结果，包含操作状态和数据信息
+            
+        Raises:
+            SARMValidationError: 当数据验证失败时抛出
+            
+        Example:
+            >>> carriers = [{
+            ...     "carrier": {
+            ...         "carrier_type": "service_address",
+            ...         "name": "example-service",
+            ...         "description": "示例服务"
+            ...     }
+                    "app_ids":["3322"],
+                    "organize_user_unique_id":"A001"
+            ... }]
+            >>> result = carrier_api.create_batch(carriers)
         """
         if not carriers:
             raise SARMValidationError("应用载体列表不能为空")
@@ -132,13 +147,12 @@ class CarrierAPI:
         # 验证数据
         carrier_data = []
         for i, carrier in enumerate(carriers):
-            if isinstance(carrier, CarrierInsert):
-                carrier_dict = carrier.dict()
-                self._validate_carrier_data(carrier_dict, i + 1)
-                carrier_data.append(carrier_dict)
-            else:
+            if isinstance(carrier, dict):
                 self._validate_carrier_data(carrier, i + 1)
                 carrier_data.append(carrier)
+            else:
+                self._validate_carrier_data(carrier.dict(), i + 1)
+                carrier_data.append(carrier.dict())
         
         # 发送请求
         response = self.client.post(
@@ -149,7 +163,7 @@ class CarrierAPI:
         return response
 
     
-    def create(self, carrier: CarrierInsert, execute_release: bool = False):
+    def create(self, carrier: Dict[str,any], execute_release: bool = False):
         """
         创建单个应用载体
         
@@ -178,15 +192,27 @@ class CarrierAPI:
         获取应用载体列表
         
         Args:
-            page: 页码
-            limit: 每页条数
-            carrier_type: 载体类型
-            name: 载体名称
-            source: 来源
+            page: 页码，默认为1
+            limit: 每页条数，默认为50，最大1000
+            carrier_type: 载体类型，可选值：code_repo, service_address, host
+            name: 载体名称，支持模糊搜索
+            source: 来源标识
             data_status: 数据状态
             
         Returns:
-            载体列表
+            Dict[str, Any]: 载体列表，包含分页信息和数据列表
+            
+        Raises:
+            SARMValidationError: 当参数验证失败时抛出
+            
+        Example:
+            >>> result = carrier_api.get_list(
+            ...     page=1,
+            ...     limit=10,
+            ...     carrier_type="code_repo",
+            ...     name="my-project"
+            ... )
+            >>> carriers = result.get('data', {}).get('list', [])
         """
         # 验证参数
         if not isinstance(page, int) or page < 1:
@@ -212,8 +238,7 @@ class CarrierAPI:
             params["source"] = source
         if data_status:
             params["data_status"] = data_status
-        print(params)
-        response = self.client.get('/api/carrier/list', params=params)
+        response = self.client.post('/api/carrier/list', params=params)
         return response
     
     def update_batch(
